% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/z.comp.R
\name{z.comp}
\alias{z.comp}
\title{Z-score computation}
\usage{
z.comp(bc.f, norm.stats.f, files.df, z.poisson = FALSE, nb.cores = 1,
  chunk.size = 10000, append = FALSE, recomp.msd = FALSE)
}
\arguments{
\item{bc.f}{the path to the normalized bin count file.}

\item{norm.stats.f}{the name of the file with the statistic of the targeted normalization run.}

\item{files.df}{a data.frame with the file paths.}

\item{z.poisson}{Should the Z-score be computed as an normal-poisson hybrid (see
Details). Default is FALSE.}

\item{nb.cores}{the number of cores to use.}

\item{chunk.size}{the chunk size. Default is 1e4. If NULL, no chunks are used.}

\item{append}{should the Z-scores be appended to existing files. Default is FALSE.}

\item{recomp.msd}{Should the mean/SD be recomputed and written to 'norm.stats.f' ? Default is FALSE. Most of the times you don't want that but it's useful when combining discordant mapping.}
}
\value{
a list with
\item{z}{a data.frame with the Z-scores if 'bc.f' was a data.frame. NULL otherwise.}
\item{fc}{a data.frame with the fold-changes if 'bc.f' was a data.frame. NULL otherwise.}
\item{msd}{a data.frame with the mean-sd information if 'bc.f' was a data.frame. NULL otherwise.}
\item{z.poisson}{was Normal-Poisson hybrid Z-score score computed.}
}
\description{
Z-score computation from bin count and/or mean/sd metrics on the reference samples.
}
\details{
The Z-score is computed by substracting the bin count by the average bin count
across the reference samples and dividing by their standard deviation. If
'z.poisson' is TRUE, a score using Poisson distribution is also computed, using
the average bin count as an estimator of the lambda. Then the score with the lowest
absolute value is kept. This hybrid Z-score is to be used when some regions have low
coverage where it is more robust to use Poisson assumptions.
}
\author{
Jean Monlong
}
